.. _api:

=================
API Documentation
=================

.. rubric:: The top-level module

.. autosummary::
    :toctree: .

    cavcalc

.. rubric:: Single-function interface

.. autosummary::
    :toctree: .

    cavcalc.calculate

.. rubric:: Output from a `calculate` call

.. autosummary::
    :toctree: .

    cavcalc.output
